@@ -23,6 +23,7 @@
 
 from gui import WidgetBase
 from jsqt import il
+from base import SimpleProp
 
 class QAbstractItemView(WidgetBase):
     def __init__(self, elt, name=None):
@@ -67,6 +68,15 @@ class Item(object):
     icon = property(get_icon, set_icon)
     value = property(get_value, set_value)
 
+class EnumSelectionMode(il.primitive.Enum):
+    value_map = {
+        "QAbstractItemView::SingleSelection": il.primitive.String("single"),
+        "QAbstractItemView::ContiguousSelection": il.primitive.String("multi"),
+        "QAbstractItemView::ExtendedSelection": il.primitive.String("additive"),
+        "QAbstractItemView::MultiSelection": il.primitive.String("additive"),
+        "QAbstractItemView::NoSelection": il.primitive.String("single"),
+    }
+
 class MItemView(object):
     def __init__(self):
         self.__items = []
@@ -78,7 +88,6 @@ class MItemView(object):
                                                        [a.name,a.icon,a.value])]
             )
             self.factory_function.add_statement(fc)
-            
 
     def add_child(self, elt):
         name = elt[0][0].text
@@ -94,11 +103,24 @@ class MItemView(object):
     def _handle_item_tag(self, elt):
         self.add_child(elt)
         
-class QListWidget(QAbstractItemView):
+class QListWidget(QAbstractItemView, MItemView):
     type = "qx.ui.form.List"
 
     def __init__(self, elt, name=None):
-        WidgetBase.__init__(self,elt,name)
+        MItemView.__init__(self)
+        QAbstractItemView.__init__(self,elt,name)
+
+    def _init_before_parse(self):
+        MItemView._init_before_parse(self)
+        QAbstractItemView._init_before_parse(self)
+
+    def compile(self, dialect, ret):
+        QAbstractItemView.compile(self, dialect, ret)
+        MItemView.compile(self, dialect, ret)
+
+    known_simple_props = {
+        "selectionMode": SimpleProp("setSelectionMode", EnumSelectionMode),
+    }
 
 class QTableWidget(QAbstractItemView):
     type="qx.ui.table.Table"
